@@ -4,10 +4,14 @@
 from trytond.pool import Pool
 from .party import *
 from .sale import *
+from . import configuration
 
 
 def register():
     Pool.register(
         Party,
+        PartySaleShipmentGroupingMethod,
         Sale,
+        configuration.Configuration,
+        configuration.ConfigurationSaleMethod,
         module='sale_shipment_grouping', type_='model')
